window.Gleam.initSearch([{"doc":"mockth","title":"mockth","content":"# mockth\n\n[![Package Version](https://img.shields.io/hexpm/v/mockth)](https://hex.pm/packages/mockth)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/mockth/)\n\nGleam modules mocking library. This is a simple wrapper around Erlang [Meck](https://github.com/eproxus/meck) library.\n\n```sh\ngleam add mockth\n```\n\n## Usage\n\nIt provides a simple API to mock Gleam modules and functions. All you need to use `mockth.expect` function to mock any external function with your own implementation.\n\n```gleam\nimport gleeunit\nimport gleeunit/should\nimport gleam/function\nimport mockth\n\npub fn main() {\n  gleeunit.main()\n}\n\npub fn expect1_test() {\n  let assert Ok(_) =\n    mockth.expect1(&quot;gleam@function&quot;, &quot;identity&quot;, fn(_) { &quot;hello&quot; })\n\n  mockth.validate(&quot;gleam@function&quot;)\n  |&gt; should.equal(True)\n\n  mockth.mocked()\n  |&gt; should.equal([&quot;gleam@function&quot;])\n\n  function.identity(&quot;world&quot;)\n  |&gt; should.equal(&quot;hello&quot;)\n\n  mockth.unload_all()\n}\n```\n\nDon&#39;t forget to unload all mocks after each test case.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/mockth&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"mockth","title":"History","content":"pub type History {\n  History(\n    pid: Pid,\n    module: String,\n    function: String,\n    arguments: List(Dynamic),\n  )\n}\n\nHistory(\n  pid: Pid,\n  module: String,\n  function: String,\n  arguments: List(Dynamic),\n)\n Module, function and arguments that the mock module got called with.\n\nSynonyms:\nmockth.History\nmockth History","url":"mockth.html#History"},{"doc":"mockth","title":"expect","content":"pub fn expect(\n  module module: String,\n  function function: String,\n  with fun: a,\n) -&gt; Result(Bool, String)\n Mock a function.\n The function `fun` should return the value that the function will return when called.\n \n pub fn expect1_test() {\n  let assert Ok(_) =\n    mockth.expect(&quot;gleam@function&quot;, &quot;identity&quot;, fn(_) { &quot;hello&quot; })\n\n  mockth.validate(&quot;gleam@function&quot;)\n  |&gt; should.equal(True)\n\n  mockth.mocked()\n  |&gt; should.equal([&quot;gleam@function&quot;])\n\n  function.identity(&quot;world&quot;)\n  |&gt; should.equal(&quot;hello&quot;)\n }\nSynonyms:\nmockth.expect\nmockth expect","url":"mockth.html#expect"},{"doc":"mockth","title":"history","content":"pub fn history(module: String) -&gt; Result(List(History), String)\n Returns the history of calls to the mocked module.\n Dont support exception handling.\nSynonyms:\nmockth.history\nmockth history","url":"mockth.html#history"},{"doc":"mockth","title":"mocked","content":"pub fn mocked() -&gt; List(String)\n Returns the currently mocked modules.\nSynonyms:\nmockth.mocked\nmockth mocked","url":"mockth.html#mocked"},{"doc":"mockth","title":"unload","content":"pub fn unload(module: String) -&gt; Result(Bool, String)\n Unload a mocked module or a list of mocked modules.\n This will purge and delete the module(s) from the Erlang virtual machine. If the mocked module(s) replaced an existing module, this module will still be in the Erlang load path and can be loaded manually or when called.\nSynonyms:\nmockth.unload\nmockth unload","url":"mockth.html#unload"},{"doc":"mockth","title":"unload_all","content":"pub fn unload_all() -&gt; List(String)\n The function returns the list of mocked modules that were unloaded in the process.\n Unloads all mocked modules from memory.\nSynonyms:\nmockth.unload_all\nmockth unload_all","url":"mockth.html#unload_all"},{"doc":"mockth","title":"validate","content":"pub fn validate(module: String) -&gt; Bool\n Validate the state of the mock module(s).\n Validation can detect:\n - When a function was called with the wrong argument types (function_clause)\n - When an exception was thrown\n - When an exception was thrown and expected (via meck:exception/2), which still results in true being returned\n\n Validation cannot detect:\n - When you didn&#39;t call a function\n - When you called a function with the wrong number of arguments (undef)\n - When you called an undefined function (undef)\nSynonyms:\nmockth.validate\nmockth validate","url":"mockth.html#validate"},{"doc":"mockth","title":"mockth","content":"","url":"mockth.html"}]);